@@ -62,6 +62,13 @@ class RESTAPI :
 
 
 
+    def get_champion_name_by_id(self, champion_id) :
+        api_url = URL['champions'].format(url='?championid={id}'.format(id=champion_id))
+        response = self.request_get(api_url)
+        return response[0]['name']
+
+
+
     def get_summoner_by_name(self, summoner_name) :
         api_url = URL['summoners'].format(url='?name={name}'.format(name=summoner_name))
         return self.request_get(api_url)
